@@ -1,7 +1,6 @@
 import json
+from typing import Union
 
-from django.core.exceptions import FieldError, ValidationError, PermissionDenied
-from django.db import ProgrammingError, DataError, IntegrityError
 from django.shortcuts import render
 from django.utils.decorators import method_decorator
 from django.views.decorators.csrf import ensure_csrf_cookie
@@ -14,10 +13,9 @@ from graphene_django.views import GraphQLView as BaseGraphQLView
 
 from graphene.utils.str_converters import to_snake_case, to_camel_case
 
-from .exceptions import APIException
 from .files import place_files_in_operations
 from ..auth import respond_handling_authentication
-from ..utils import AuthError, PermissionDenied
+from ..settings import PROTECT_GRAPHQL
 
 
 class ResponseError(Exception):
@@ -60,38 +58,39 @@ class GraphQLView(BaseGraphQLView):
 
     @method_decorator(ensure_csrf_cookie)
     def dispatch(self, request, *args, **kwargs):
-        try:
-            if request.method.lower() not in ("get", "post", "options"):
-                raise HttpError(
-                    HttpResponseNotAllowed(
-                        ["GET", "POST", "OPTIONS"], "GraphQL only supports GET, POST and OPTIONS requests."
-                    )
+        if request.method.lower() not in ("get", "post", "options"):
+            raise HttpError(
+                HttpResponseNotAllowed(
+                    ["GET", "POST", "OPTIONS"], "Only supports GET, POST and OPTIONS requests."
                 )
-
+            )
+        allowGraphiQL = self.graphiql and not PROTECT_GRAPHQL
+        if request and request.user and request.user.is_staff:
+            allowGraphiQL = True
+        if allowGraphiQL:
             data = self.parse_body(request)
-            allowGraphiQL = self.graphiql
-            if request and request.user and request.user.is_staff:
-                allowGraphiQL = True
-
-            if allowGraphiQL and self.can_display_graphiql(request, data):
+            if self.can_display_graphiql(request, data):
                 return render(request, "graphiql/graphiql.html")
-
-            if self.batch:
-                responses = [self.get_response(request, entry) for entry in data]
-                result = "[{}]".format(",".join([response[0] for response in responses]))
-                status_code = (responses and max(responses, key=lambda response: response[1])[1] or 200)
-            else:
-                result, status_code = self.get_response(
-                    request, data,
-                    allowGraphiQL and self.can_display_graphiql(request, data)
+        if PROTECT_GRAPHQL and request.method.lower() not in "post":
+            raise HttpError(
+                HttpResponseNotAllowed(
+                    ["POST"], "Only supports POST requests."
                 )
+            )
+        try:
+            if self.batch:
+                raise HttpError(
+                    HttpResponseNotAllowed("Batch queries not supported")
+                )
+            data = self.parse_body(request)
+            result, status_code = self.get_response(request, data)
             return respond_handling_authentication(status_code=status_code, result=json.loads(result), request=request)
-
         except HttpError as e:
-            response = e.response
-            response["Content-Type"] = "application/json"
-            response.content = self.json_encode(request, {"errors": [self.format_error(e)]})
-            return response
+            return respond_handling_authentication(
+                status_code=e.response.code,
+                result={"errors": [self.format_error(e)]},
+                request=request
+            )
 
     def parse_body(self, request):
         """Handle multipart request spec for multipart/form-data"""
@@ -106,12 +105,6 @@ class GraphQLView(BaseGraphQLView):
             )
         return super(GraphQLView, self).parse_body(request)
 
-    @staticmethod
-    def encode_code(code):
-        if code is None:
-            return None
-        return to_kebab_case(code)
-
     @staticmethod
     def encode_params(params):
         if params is None:
@@ -126,52 +119,30 @@ class GraphQLView(BaseGraphQLView):
                 locations.append({"line": loc.line, "column": loc.column})
             return locations
 
-    def format_response_error(self, error: ResponseError):
-        return {
-            'message': error.message,
-            'code': self.encode_code(error.code),
-            'params': self.encode_params(error.params),
-        }
-
-    def format_located_error(self, error):
-        if (
-            isinstance(error, AuthError) or isinstance(error, PermissionDenied) or isinstance(error, APIException)
-        ):
-            return {"message": error.message, "code": error.code}
-        if isinstance(error, GraphQLLocatedError):
-            return self.format_response_error(error)
-        if isinstance(error, ResponseError):
-            return self.format_response_error(error)
-        if isinstance(error, ValidationError):
-            return {"message": error.__repr__(), "code": error.code}
-        if isinstance(error, PermissionDenied):
-            return {"message": error.__repr__(), "code": "PERMISSION_DENIED"}
-        if isinstance(error, DataError):
-            return {"message": error.__repr__(), "code": "DATA_ERROR"}
-        if isinstance(error, FieldError):
-            return {"message": error.__repr__(), "code": "FIELD_ERROR"}
-        if isinstance(error, ProgrammingError):
-            return {"message": error.__repr__(), "code": "DB_PROGRAMING_ERROR"}
-        if isinstance(error, IntegrityError):
-            return {"message": error.__repr__(), "code": "INTEGRITY_ERROR"}
-        if isinstance(error, AttributeError):
-            return {"message": error.__repr__(), "code": "ATTRIBUTE_ERROR"}
-        if isinstance(error, TypeError):
-            return {"message": error.__repr__(), "code": "TYPE_ERROR"}
-        if isinstance(error, KeyError):
-            return {"message": error.__repr__(), "code": "KEY_ERROR"}
-        return self.format_response_error(error)
+    def format_response_error(self, error: Union[ResponseError, Exception]):
+        returnObj = {}
+        if hasattr(error, 'message') and error.message:
+            returnObj['message'] = error.message
+        if hasattr(error, 'code') and error.code:
+            returnObj['code'] = error.code
+        if hasattr(error, 'params') and error.params:
+            returnObj['params'] = self.encode_params(error.params)
+        return returnObj
 
     def format_error(self, error):
         if isinstance(error, GraphQLLocatedError):
-            return self.format_located_error(error.original_error)
+            return self.format_response_error(error.original_error)
         if isinstance(error, GraphQLSyntaxError):
+            if PROTECT_GRAPHQL:
+                return {"message": "Invalid Request", "code": "SYNTAX_ERROR"}
             return {
                 "message": error.message,
                 "location": self.get_locations(error),
                 "code": "GRAPHQL_SYNTAX_ERROR"
             }
         if isinstance(error, GraphQLError):
+            if PROTECT_GRAPHQL:
+                return {"message": "This request could not be processed", "code": "BAD_REQUEST"}
             return {
                 "message": error.message,
                 "location": self.get_locations(error),
